#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import wx
from wx.lib import newevent
import blueSMSsender_PhoneBook
import blueSMSsender_Message
import sys
from wx.lib.mixins.listctrl import ListCtrlAutoWidthMixin
from wx.lib.mixins.listctrl import TextEditMixin
import csv
import blueSMSsender_Config
import blueSMSsender_SQLliteDB
import blueSMSsender_Serial
import blueSMSsender_Bluetooth
from blueSMSsender_exceptions import NoCustomersList
import thread
import webbrowser
import os
import time

(setSendButton, EVT_UPDATE_SENDBTN) = newevent.NewEvent()
(setStatusBar, EVT_UPDATE_STATUSBAR) = newevent.NewEvent()
(setCellListCtrl, EVT_UPDATE_LISTCTRL) = newevent.NewEvent()
PLATFORM=sys.platform

class SearchThreads:
    def __init__(self,mthread):
        self.mthread=mthread
        self.SendRunning = False
        
    def Start(self):
        thread.start_new_thread(self.SendSMS, ())
            
    def SendSMS(self):
        self.SendRunning = True
        try:
            db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
            if PLATFORM.startswith('win'):
                data = db.sel_com(active=1)[0][1]
            else:
                data = db.sel_bluetooth(active=1)[0]
            db.exit()
            try:
                evt = setStatusBar(value = _('Connecting...'))
                wx.PostEvent(self.mthread, evt)
                if PLATFORM.startswith('win'):
                    btd = blueSMSsender_Serial.blueSMSsender_Serial(data)
                else:
                    btd = blueSMSsender_Bluetooth.blueSMSsender_Bluetooth(True)
                    btd.connect(str(data[2]),int(data[3]))
                evt = setStatusBar(value = _('Connected'))
                wx.PostEvent(self.mthread, evt)
            except:
                btd.Close()
                self.SendRunning = False
                evt = setSendButton(value = True)
                wx.PostEvent(self.mthread, evt)
                errore=_('Error: ')+str(sys.exc_info()[1])
                dlg = wx.MessageDialog(self.mthread,errore,_('Error'),wx.OK | wx.ICON_ERROR)
                dlg.ShowModal()
            totalrow = self.mthread.blueSMSsender_ListCtrl.GetItemCount()
            for row in range(totalrow):
                evt = setStatusBar(value = _('Sending...'))
                wx.PostEvent(self.mthread, evt)
                if self.mthread.blueSMSsender_ListCtrl.GetItem(row,4).GetText() != _('Not sent'):
                    evt = setCellListCtrl(row = row, col = 4, value = _('Skipped'))
                    wx.PostEvent(self.mthread, evt)
                else:
                    if self.mthread.keepGoing == False: break
                    number = self.mthread.blueSMSsender_ListCtrl.GetItem(row,1).GetText()
                    message = self.mthread.blueSMSsender_ListCtrl.GetItem(row,3).GetText()
                    try:
                        btd.Send(str(number), str(message))
                        evt = setCellListCtrl(row = row, col = 4, value = _('Sent'))
                        wx.PostEvent(self.mthread, evt)
                        if row == totalrow-1:
                            evt = setStatusBar(value = _('...disconnection'))
                            wx.PostEvent(self.mthread, evt)
                        else:
                            evt = setStatusBar(value = _('Sent...next sending in 10 seconds'))
                            wx.PostEvent(self.mthread, evt)
                        time.sleep(10)
                    except:
                        btd.Close()
                        evt = setStatusBar(value = _('Send error'))
                        wx.PostEvent(self.mthread, evt)
                        evt = setSendButton(value = True)
                        wx.PostEvent(self.mthread, evt)
                        evt = setCellListCtrl(row = row, col = 4, value = _('Send error'))
                        wx.PostEvent(self.mthread, evt)
            btd.Close()
            evt = setStatusBar(value = _('Send done'))
            wx.PostEvent(self.mthread, evt)
        except IndexError:
            errore=_('No device selected in preferences')
            dlg = wx.MessageDialog(self.mthread,errore,_('Error'),wx.OK | wx.CANCEL | wx.ICON_WARNING)
            dlg.ShowModal()
        except NoCustomersList:
            errore=_('Error: Nothing to send\nInsert values into the list')
            dlg = wx.MessageDialog(self.mthread,errore,_('Error'),wx.OK | wx.ICON_ERROR)
            dlg.ShowModal()
        except AttributeError:
            pass
        except:
            errore=_('Generic error')
            dlg = wx.MessageDialog(self.mthread,errore,_('Error'),wx.OK | wx.ICON_ERROR)
            dlg.ShowModal()
        finally:
            evt = setSendButton(value = True)
            wx.PostEvent(self.mthread, evt)
            self.SendRunning = False

class blueSMSsender_ListCtrl(wx.ListCtrl,ListCtrlAutoWidthMixin,TextEditMixin):
    def __init__(self,parent,id):
        wx.ListCtrl.__init__(self, parent, id, style=wx.LC_REPORT|wx.LC_HRULES|wx.LC_VRULES)
        ListCtrlAutoWidthMixin.__init__(self)
        TextEditMixin.__init__(self)

class blueSMSsenderFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: blueSMSsenderFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, size=(800,700),*args, **kwds)
        self.blueSMSsender_ButtonPanel = wx.Panel(self, -1)
        
        # Menu Bar
        self.blueSMSsenderFrame_MenuBar = wx.MenuBar()
        wxglade_tmp_menu = wx.Menu()
        new = wx.MenuItem(wxglade_tmp_menu, wx.ID_NEW, _("New"), _("Create a new row"), wx.ITEM_NORMAL)
        new.SetBitmap(wx.Bitmap("./data/New.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(new)
        open = wx.MenuItem(wxglade_tmp_menu, wx.ID_OPEN, _("Open"), _("Open saved messages list"), wx.ITEM_NORMAL)
        open.SetBitmap(wx.Bitmap("./data/open.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(open)
        save = wx.MenuItem(wxglade_tmp_menu, wx.ID_SAVE, _("Save"), _("Save the current status of the messages list"), wx.ITEM_NORMAL)
        save.SetBitmap(wx.Bitmap("./data/save.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(save)
        wxglade_tmp_menu.AppendSeparator()
        config = wx.MenuItem(wxglade_tmp_menu, wx.ID_PREFERENCES, _("Preferences"), _("Open preference view for bluetooth device discovering"), wx.ITEM_NORMAL)
        config.SetBitmap(wx.Bitmap("./data/Config.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(config)
        clear = wx.MenuItem(wxglade_tmp_menu, wx.ID_CLEAR, _("Clear"), _("Clear current messages list"), wx.ITEM_NORMAL)
        clear.SetBitmap(wx.Bitmap("./data/clear.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(clear)
        wxglade_tmp_menu.AppendSeparator()
        wxglade_tmp_menu.Append(wx.ID_EXIT, _("Exit"), _("Quit this program"), wx.ITEM_NORMAL)
        self.blueSMSsenderFrame_MenuBar.Append(wxglade_tmp_menu, _("File"))
        wxglade_tmp_menu = wx.Menu()
        #help = wx.MenuItem(wxglade_tmp_menu, wx.ID_HELP, "Help", "", wx.ITEM_NORMAL)
        #help.SetBitmap(wx.Bitmap("./data/help.ico", wx.BITMAP_TYPE_ANY))
        #wxglade_tmp_menu.AppendItem(help)
        #wxglade_tmp_menu.AppendSeparator()
        wxglade_tmp_menu.Append(wx.ID_ABOUT, _("About..."), _("Show about dialog"), wx.ITEM_NORMAL)
        self.blueSMSsenderFrame_MenuBar.Append(wxglade_tmp_menu, "?")
        self.SetMenuBar(self.blueSMSsenderFrame_MenuBar)
        # Menu Bar end
        self.blueSMSsenderFrame_StatusBar = self.CreateStatusBar()
        self.ID_LIST = wx.NewId()
        self.blueSMSsender_ListCtrl = blueSMSsender_ListCtrl(self, self.ID_LIST)
        self.blueSMSsender_NewButton = wx.Button(self.blueSMSsender_ButtonPanel, wx.ID_NEW, _("New row"))
        self.blueSMSsender_DelButton = wx.Button(self.blueSMSsender_ButtonPanel, wx.ID_CANCEL, _("Delete selected row"))
        self.blueSMSsender_ClearButton = wx.Button(self.blueSMSsender_ButtonPanel, wx.ID_CLEAR, _("Clear"))
        self.blueSMSsender_PhonebookButton = wx.Button(self.blueSMSsender_ButtonPanel, wx.ID_EDIT, _("Phonebook"))
        self.blueSMSsender_SendButton = wx.ToggleButton(self.blueSMSsender_ButtonPanel, wx.ID_OK, _("Send"))
        self.ID_SELECT = wx.NewId()
        self.blueSMSsender_CancelButton = wx.Button(self.blueSMSsender_ButtonPanel, self.ID_SELECT, _("Messages"))
        self.blueSMSsender_CloseButton = wx.Button(self.blueSMSsender_ButtonPanel, wx.ID_EXIT, _("Exit"))

        self.__set_properties()
        self.__do_layout()
        self.__do_evt()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: blueSMSsenderFrame.__set_properties
        self.SetTitle("blueSMSsender")
        _icon = wx.Icon("./data/blueSMSsender48.ico",wx.BITMAP_TYPE_ICO)
        self.SetIcon(_icon)
        self.blueSMSsender_ListCtrl.InsertColumn(0, _("Name"))
        self.blueSMSsender_ListCtrl.SetColumnWidth(0,wx.LIST_AUTOSIZE_USEHEADER)
        self.blueSMSsender_ListCtrl.InsertColumn(1, _("Telephone number"))
        self.blueSMSsender_ListCtrl.SetColumnWidth(1,wx.LIST_AUTOSIZE_USEHEADER)
        self.blueSMSsender_ListCtrl.InsertColumn(2, _("Extra word to replace with..."))
        self.blueSMSsender_ListCtrl.SetColumnWidth(2,wx.LIST_AUTOSIZE_USEHEADER)
        self.blueSMSsender_ListCtrl.InsertColumn(3, _("Message"))
        self.blueSMSsender_ListCtrl.SetColumnWidth(3,wx.LIST_AUTOSIZE_USEHEADER)
        self.blueSMSsender_ListCtrl.InsertColumn(4, _("Status"))
        self.blueSMSsender_ListCtrl.SetColumnWidth(4,wx.LIST_AUTOSIZE_USEHEADER)
        self.blueSMSsenderFrame_StatusBar.SetStatusText("blueSMSsender")
        # end wxGlade
        self.wildcard = "CSV Comma delimited (*.csv)|*.csv|"\
                        "All files (*.*)|*.*"                        

    def __do_layout(self):
        # begin wxGlade: blueSMSsenderFrame.__do_layout
        blueSMSsender_VSizer = wx.BoxSizer(wx.VERTICAL)
        blueSMSsender_ButtonSizer = wx.BoxSizer(wx.HORIZONTAL)
        blueSMSsender_VSizer.Add(self.blueSMSsender_ListCtrl, 1, wx.EXPAND, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_NewButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_DelButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_ClearButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_PhonebookButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_SendButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_CancelButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        blueSMSsender_ButtonSizer.Add(self.blueSMSsender_CloseButton, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 5)
        self.blueSMSsender_ButtonPanel.SetSizer(blueSMSsender_ButtonSizer)
        blueSMSsender_VSizer.Add(self.blueSMSsender_ButtonPanel, 0, wx.EXPAND|wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 0)
        self.SetSizer(blueSMSsender_VSizer)
        self.Layout()
        self.Centre()
        # end wxGlade
        
    def __do_evt(self):
        self.Bind(wx.EVT_MENU, self.OnNew, id=wx.ID_NEW)
        self.Bind(wx.EVT_BUTTON, self.OnNew, id=wx.ID_NEW)
        self.Bind(wx.EVT_BUTTON, self.ShowPhoneBook, id=wx.ID_EDIT)
        self.Bind(wx.EVT_MENU, self.OnEsci, id=wx.ID_EXIT)
        self.Bind(wx.EVT_BUTTON, self.OnEsci, id=wx.ID_EXIT)
        self.Bind(wx.EVT_BUTTON, self.OnReset, id=wx.ID_CLEAR)
        self.Bind(wx.EVT_BUTTON, self.ShowMessage, id=self.ID_SELECT)
        self.Bind(wx.EVT_MAXIMIZE, self.OnMaximize)
        self.Bind(wx.EVT_MENU, self.OnOpen, id=wx.ID_OPEN)
        self.Bind(wx.EVT_MENU, self.OnSave, id=wx.ID_SAVE)
        self.Bind(wx.EVT_MENU, self.ShowConfig, id=wx.ID_PREFERENCES)
        self.Bind(wx.EVT_TOGGLEBUTTON, self.OnSend, id=wx.ID_OK)
        self.Bind(wx.EVT_CLOSE, self.OnEsci)
        self.Bind(wx.EVT_BUTTON, self.OnDelete, id=wx.ID_CANCEL)
        self.Bind(wx.EVT_MENU, self.OnAbout, id=wx.ID_ABOUT)
        self.Bind(wx.EVT_LIST_BEGIN_LABEL_EDIT, self.OnEdit, self.blueSMSsender_ListCtrl, id=self.ID_LIST)
        #self.Bind(wx.EVT_MENU, self.OnHelp, id=wx.ID_HELP)
        self.Bind(EVT_UPDATE_SENDBTN, self.setSendButton)
        self.Bind(EVT_UPDATE_STATUSBAR, self.setStatusBar)
        self.Bind(EVT_UPDATE_LISTCTRL, self.setListCtrl)
    
    def setListCtrl(self,event):
        self.blueSMSsender_ListCtrl.SetStringItem(event.row,event.col,event.value)

    def setStatusBar(self,event):
        self.blueSMSsenderFrame_StatusBar.SetStatusText(event.value)
    
    def setSendButton(self,event):
        if event.value:
            self.blueSMSsender_SendButton.SetLabel(_("Send"))
            self.blueSMSsender_SendButton.SetValue(False)
        else:
            self.blueSMSsender_SendButton.SetLabel(_("Cancel"))
            self.blueSMSsender_SendButton.SetValue(True)
        
    def OnHelp(self,event):
        url = os.path.abspath("./help/index.html")
        webbrowser.open(url)
        
    def OnEdit(self,event):
        if event.GetColumn() == 4:
            event.Veto()
        
    def IsEmpyCheckListCtrl(self):
        self.EmpyItem = []
        for row in range(0,self.blueSMSsender_ListCtrl.GetItemCount()):
            for clm in range(0,4):
                if self.blueSMSsender_ListCtrl.GetItem(row,clm).GetText() == '':
                    flag = True
                    self.EmpyItem.append(row)
                    self.EmpyItem.append(clm)
                    break
                else:
                    flag = False
        return flag
            
    def OnAbout(self,event):
        description=_(u"This application allow to send SMS from phone connected throw bluetooth connection.")
        license=u"""blueSMSsender is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.\n\nblueSMSsender is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with Regressione Fatture; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA."""
        info = wx.AboutDialogInfo()
        info.SetIcon(wx.Icon('./data/blueSMSsender48.ico', wx.BITMAP_TYPE_ANY))
        info.SetName('blueSMSsender')
        info.SetVersion('0.1')
        info.SetDescription(description)
        info.SetCopyright('Copyright (C) 2007 Giuseppe Buzzanca')
        info.SetLicence(license)
        info.AddDeveloper('Giuseppe Buzzanca <giuseppebuzzanca@gmail.com>')
        info.SetWebSite('mailto:giuseppebuzzanca@gmail.com')
        wx.AboutBox(info)
        
    def OnSend(self,event):
        if self.blueSMSsender_SendButton.GetValue():
            if self.blueSMSsender_ListCtrl.GetItemCount() > 0:
                if not self.CheckSizeLimit():
                    if self.IsEmpyCheckListCtrl():
                        dlg = wx.MessageDialog(self,_("Missing value into row %d and column %d") % (self.EmpyItem[0]+1,self.EmpyItem[1]+1),_('Error'),wx.OK | wx.ICON_WARNING)
                        dlg.ShowModal()
                        self.blueSMSsender_SendButton.SetValue(False)
                    else:
                        self.blueSMSsender_SendButton.SetLabel(_('Stop'))
                        self.keepGoing = True
                        st = SearchThreads(self)
                        st.Start()
                else:
                    self.blueSMSsender_SendButton.SetValue(False)
            else:
                dlg = wx.MessageDialog(self,_('No message to send'),_('Caution'),wx.OK | wx.ICON_WARNING)
                dlg.ShowModal()
                self.blueSMSsender_SendButton.SetValue(False)
        else:
            self.keepGoing = False
        
    def OnOpen(self,event):
        dial=wx.FileDialog(self,_("Open file"),os.path.expanduser('~'),wildcard=self.wildcard)
        if dial.ShowModal() == wx.ID_OK:
            csvfile = csv.reader(open(dial.GetPath()),delimiter=';')
            self.blueSMSsender_ListCtrl.DeleteAllItems()
            for row in csvfile:
                cidx = 1
                ridx = self.blueSMSsender_ListCtrl.InsertStringItem(sys.maxint,row[0])
                for item in row[1:]:
                    self.blueSMSsender_ListCtrl.SetStringItem(ridx,cidx,item)
                    cidx = cidx + 1
            for row in range(0,self.blueSMSsender_ListCtrl.GetItemCount()):
                if self.blueSMSsender_ListCtrl.GetItem(row,4).GetText() == '':
                    self.blueSMSsender_ListCtrl.SetStringItem(row,4,_('Not sent'))
                
    def OnSave(self,event):
        filename=_("SMSSent")+time.strftime('%Y%m%d')+".csv"
        dlg = wx.FileDialog(self, _("Save file"), os.path.expanduser('~'),filename, wildcard=self.wildcard, style=wx.SAVE)
        if dlg.ShowModal() == wx.ID_OK:
            csvfile = csv.writer(open(dlg.GetPath(),'wb'),delimiter=';',lineterminator='\n')
            for row in range(0,self.blueSMSsender_ListCtrl.GetItemCount()):
                tmp = []
                tmp.append(self.blueSMSsender_ListCtrl.GetItem(row,0).GetText())
                tmp.append(self.blueSMSsender_ListCtrl.GetItem(row,1).GetText())
                tmp.append(self.blueSMSsender_ListCtrl.GetItem(row,2).GetText())
                tmp.append(self.blueSMSsender_ListCtrl.GetItem(row,3).GetText())
                tmp.append(self.blueSMSsender_ListCtrl.GetItem(row,4).GetText())
                csvfile.writerow(tmp)
                
    def OnMaximize(self,event):
        while not self.IsMaximized():
            pass
        self.ListAutosize()
        
    def OnNew(self,event):
        index = self.blueSMSsender_ListCtrl.InsertStringItem(sys.maxint,'')
        self.blueSMSsender_ListCtrl.SetStringItem(index,4,_('Not sent'))
            
    def ListAutosize(self):
        self.blueSMSsender_ListCtrl.SetColumnWidth(0,150)
        self.blueSMSsender_ListCtrl.SetColumnWidth(1,150)
        self.blueSMSsender_ListCtrl.SetColumnWidth(2,150)
        if self.blueSMSsender_ListCtrl.GetItemCount() > 0:
            for col in range(3,self.blueSMSsender_ListCtrl.GetColumnCount()):
                self.blueSMSsender_ListCtrl.SetColumnWidth(col,wx.LIST_AUTOSIZE)
            
    def ShowPhoneBook(self,event):
        Mask=blueSMSsender_PhoneBook.blueSMSsender_PhoneBook(self,-1,_("Phonebook"))
        Mask.Show(1)
    
    def ShowConfig(self,event):
        Mask=blueSMSsender_Config.blueSMSsender_Config(self,-1,_("Configurations"))
        Mask.Show(1)
        
    def ShowMessage(self,event):
        Mask=blueSMSsender_Message.blueSMSsender_Message(self,-1,_("Messages"))
        Mask.Show(1)
        
    def InsCustList(self,items):
        presence = False
        for idx in range(0,self.blueSMSsender_ListCtrl.GetItemCount()):
            data = (self.blueSMSsender_ListCtrl.GetItem(idx).GetText(),self.blueSMSsender_ListCtrl.GetItem(idx,1).GetText())
            if data[0] == items[0] and data[1] == items[1]:
                presence = True
                break
            else:
                presence = False
        if not presence:
            index = self.blueSMSsender_ListCtrl.InsertStringItem(sys.maxint,items[0])
            self.blueSMSsender_ListCtrl.SetStringItem(index,1,items[1])
            self.blueSMSsender_ListCtrl.SetStringItem(index,4,_('Not sent'))
            
    def InsMessage(self,message):
        cnt = self.blueSMSsender_ListCtrl.GetItemCount()
        if cnt > 0:
            for idx in range(0,cnt):
                nome = self.blueSMSsender_ListCtrl.GetItem(idx).GetText()
                extra = self.blueSMSsender_ListCtrl.GetItem(idx,2).GetText()
                tmp = message.replace('<NAME>',nome).replace('<EXTRA>',extra)                
                self.blueSMSsender_ListCtrl.SetStringItem(idx,3,tmp)
            self.CheckSizeLimit()
    
    def CheckSizeLimit(self):
        OverSizelimit = []
        for idx in range(0,self.blueSMSsender_ListCtrl.GetItemCount()):
            nome = self.blueSMSsender_ListCtrl.GetItem(idx).GetText()
            message = self.blueSMSsender_ListCtrl.GetItem(idx,3).GetText()
            if len(message) > 160:
                OverSizelimit.append(nome)
        if len(OverSizelimit) > 0:
            list = ''
            for item in OverSizelimit:
                list += str(item)+'\n'
            dlg = wx.MessageDialog(self,_('This message is more long of 160 characters:\n')+list,_('Error'),wx.OK | wx.ICON_WARNING)
            dlg.ShowModal()
            return True
        else:
            return False
    
    def OnDelete(self,event):
        tot = self.blueSMSsender_ListCtrl.GetItemCount()
        if tot > 0:
            for idx in range(0,tot):
                if self.blueSMSsender_ListCtrl.IsSelected(idx):
                    self.blueSMSsender_ListCtrl.DeleteItem(idx)
                
    def OnReset(self,event):
        self.blueSMSsender_ListCtrl.DeleteAllItems()
            
    def OnEsci(self,event):
        dial = wx.MessageDialog(self, _('Are you sure want exit?'), _('Caution'),wx.YES_NO | wx.NO_DEFAULT | wx.ICON_QUESTION)
        ret=dial.ShowModal()
        if ret == wx.ID_YES:
            self.Destroy()

# end of class blueSMSsenderFrame
