#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import bluetooth
import blueSMSsender_exceptions
import os
import datetime
import logging

class blueSMSsender_Bluetooth:
    
    def __init__(self,fCnt=False):
        if fCnt == False:
            NoAdapter = blueSMSsender_exceptions.NoAdapter()
            temp = bluetooth.discover_devices(lookup_names=True)
            self.devs = []
            try:
                for dev in temp:
                    try:
                        self.devs.index(dev)
                    except:
                        self.devs.append(dev)
            except IOError:
                raise NoAdapter
        else:
            self.__connect = False
    
    def connect(self, address, channel):
        try:
            self.__connect = True
            self.__connection = bluetooth.BluetoothSocket(bluetooth.RFCOMM)
            self.__connection.connect((address, channel))
            filelog=os.path.expanduser("~/.blueSMSsender/")
            if not os.path.isdir(filelog):
                os.mkdir(filelog)
            LOG_FILENAME = filelog+'blueSMSsender_'+datetime.datetime.now().strftime('%Y%m%d%H%M%S')+'.log'
            logging.basicConfig(filename=LOG_FILENAME,level=logging.DEBUG)
            self.log =  logging.getLogger("blueSMSsender_Bluetooth.connect")
            self.__sendATCommand('ATE0')
            self.__sendATCommand('ATZ')
            self.__sendATCommand('AT+CMGF=1')
            characterSets = self.__getSupportedCharacterSets()
            if '"8859-1"' in characterSets:
                self.__setCharacterSet('"8859-1"')
                self.fEncode="8859-1"
        except:
            self.log.error("Connection Error")
            self.__connect = False
            self.__raiseOnNoneSocket('BluetoothConnection: connection error')
                    
    def __setCharacterSet(self, characterSet):
        self.__sendATCommand('AT+CSCS=' + characterSet)
        
    def __getSupportedCharacterSets(self):
        response = self.__sendATCommand('AT+CSCS=?')
        return self.__parseCommaseperatedList(response)
    
    def __parseCommaseperatedList(self, list):
        start = list.find('(') + 1
        end = list.rfind(')')
        return list[start:end].split(',')
    
    def DiscoverService(self):
        dev_list = []
        for dev in self.devs:
            servs = bluetooth.find_service(uuid=bluetooth.DIALUP_NET_CLASS,address=dev[0])
            for serv in servs:
                dev_list.append((dev[1],dev[0],serv["port"]))
        return dev_list
    
    def Send(self, number, message):
        if self.__connect == True:
            if self.fEncode == '"8859-1"': message = message.encode('iso-8859-1')
            self.__sendATCommand('AT+CMGS="' + number + '"\r')
            self.__sendATCommand(message + chr(26), False)
        else:
            self.__raiseOnNoneSocket('BluetoothConnection: not connected')
        
    def __sendATCommand(self, atCommand, lineBreak = True):
        command = atCommand
        if lineBreak:
            command += '\r'
        self.__connection.send(command) 
        reply = ''
        while not (reply.endswith(('OK\r\n','ERROR\r\n','> '))):
            reply += self.recv()
            self.log.info(str(reply))
            if reply.find('+CMS ERROR') != -1: break
        if reply.endswith(('OK\r\n','> ')):
            end = reply.rfind('\r\nOK\r\n')
            return reply[2:end]
        else:
            self.__raiseOnNoneSocket('AT Command not supported by phone: '+atCommand[:-1])
    
    def recv(self, size = 2048):
        if self.__connect == True:
            return self.__connection.recv(size)
        else:
            self.__raiseOnNoneSocket('BluetoothConnection: not connected')
        
    def __raiseOnNoneSocket(self, message):
        raise blueSMSsender_exceptions.BluetoothConnectionException, message

    def Close(self):
        if self.__connect == True:
            self.__connection.close()
            self.__connect = False
        else:
            self.__raiseOnNoneSocket('BluetoothConnection: not connected')
