#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import wx
from wx import animate
import blueSMSsender_Bluetooth
import blueSMSsender_SQLliteDB
from blueSMSsender_exceptions import NoDeviceChecked
import thread
from wx.lib import newevent
import time
import sys

(UpdateListCtrl, EVT_UPDATE_LISTCTRL) = newevent.NewEvent()
(UpdateListCtrlCom, EVT_UPDATE_LISTCTRLCOM) = newevent.NewEvent()
(UpdateTitle, EVT_UPDATE_TITLE) = newevent.NewEvent()
PLATFORM=sys.platform

class SearchThreads:
    def __init__(self,mthread):
        self.mthread = mthread
        self.SearchRunning = False
        self.dev_cnt = 0
        
    def Start(self):
        if PLATFORM.startswith('win'):
            thread.start_new_thread(self.RunSearchCom, ())
        else:
            thread.start_new_thread(self.RunCtrl, ())
        
    def RunSearchCom(self):
        db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
        com_data = db.sel_com()
        db.exit()
        evt = UpdateListCtrlCom(data = com_data)
        wx.PostEvent(self.mthread, evt)
        tmp = len(com_data)
        if tmp > 1:
            evt = UpdateTitle(value = _("Found %d devices") % tmp)
        else:
            evt = UpdateTitle(value = _("Found %d devices") % tmp)
        wx.PostEvent(self.mthread, evt)
                
    def RunSearch(self):
        BTDevs = blueSMSsender_Bluetooth.blueSMSsender_Bluetooth()
        dev_list = BTDevs.DiscoverService()
        if dev_list != None:
            db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
            db.ins_bluetooth(dev_list)
            db.exit()
            self.dev_cnt = len(dev_list)
        self.SearchRunning = False
            
    def RunCtrl(self):
        self.SearchRunning = True
        thread.start_new_thread(self.RunSearch, ())
        cnt = 0
        while self.SearchRunning:
            time.sleep(1)
            cnt += 1
            evt = UpdateTitle(value = _("Searching: %d seconds") % cnt)
            wx.PostEvent(self.mthread, evt)
            if cnt == 60:
                self.SearchRunning = False
        db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
        pb_data = db.sel_bluetooth()
        db.exit()
        evt = UpdateListCtrl(data = pb_data)
        wx.PostEvent(self.mthread, evt)
        if self.dev_cnt > 1:
            evt = UpdateTitle(value = _("Found %d devices") % self.dev_cnt)
        else:
            evt = UpdateTitle(value = _("Found %d device") % self.dev_cnt)
        wx.PostEvent(self.mthread, evt)

class blueSMSsender_Config(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: blueSMSsender_Config.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, size=(300, 400), *args, **kwds)
        self.blueSMSsender_Config_Panel = wx.Panel(self, -1)
        self.blueSMSsender_Config_CListBox = wx.CheckListBox(self.blueSMSsender_Config_Panel, -1, choices=[])
        self.ID_SEARCH=wx.NewId()
        if PLATFORM.startswith('win'):
            self.blueSMSsender_Config_Search_Button = wx.BitmapButton(self.blueSMSsender_Config_Panel, self.ID_SEARCH, wx.Bitmap("./data/update.ico", wx.BITMAP_TYPE_ANY))
        else:
            self.blueSMSsender_Config_Search_Button = wx.BitmapButton(self.blueSMSsender_Config_Panel, self.ID_SEARCH, wx.Bitmap("./data/bluetooth.ico", wx.BITMAP_TYPE_ANY))
        self.blueSMSsender_Config_OK_Button = wx.BitmapButton(self.blueSMSsender_Config_Panel, wx.ID_OK, wx.Bitmap("./data/ok.ico", wx.BITMAP_TYPE_ANY))
        self.blueSMSsender_Config_DEL_Button = wx.BitmapButton(self.blueSMSsender_Config_Panel, wx.ID_DELETE, wx.Bitmap("./data/delete32.ico", wx.BITMAP_TYPE_ANY))
        self.__do_layout()
        self.__set_properties()
        self.__do_evt()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: blueSMSsender_Config.__set_properties
        self.SetTitle(_("Config"))
        _icon = wx.EmptyIcon()
        _icon.CopyFromBitmap(wx.Bitmap("./data/Config.ico", wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)
        if PLATFORM.startswith('win'):
            self.blueSMSsender_Config_Search_Button.SetBitmapDisabled(wx.Bitmap("./data/update_disable.ico", wx.BITMAP_TYPE_ANY))
        else:
            self.blueSMSsender_Config_Search_Button.SetBitmapDisabled(wx.Bitmap("./data/bluetooth_disable.ico", wx.BITMAP_TYPE_ANY))
        self.blueSMSsender_Config_Search_Button.SetSize(self.blueSMSsender_Config_Search_Button.GetBestSize())
        self.blueSMSsender_Config_OK_Button.SetSize(self.blueSMSsender_Config_OK_Button.GetBestSize())
        self.blueSMSsender_Config_DEL_Button.SetSize(self.blueSMSsender_Config_DEL_Button.GetBestSize())
        # end wxGlade
        db = blueSMSsender_SQLliteDB
        self.pb = db.blueSMSsender_Sdb()
        if PLATFORM.startswith('win'):
            self.AddDevices(None)
        else:
            pb_data = self.pb.sel_bluetooth()
            self.InsCListCtrl(pb_data)
        self.pb.exit()

    def __do_layout(self):
        # begin wxGlade: blueSMSsender_Config.__do_layout
        blueSMSsender_Config_Sizer = wx.BoxSizer(wx.VERTICAL)
        blueSMSsender_Config_VSizer = wx.BoxSizer(wx.VERTICAL)
        blueSMSsender_Config_HSizer = wx.BoxSizer(wx.HORIZONTAL)
        blueSMSsender_Config_VSizer.Add(self.blueSMSsender_Config_CListBox, 1, wx.TOP|wx.RIGHT|wx.LEFT|wx.EXPAND, 10)
        blueSMSsender_Config_HSizer.Add(self.blueSMSsender_Config_Search_Button, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 10)
        blueSMSsender_Config_HSizer.Add(self.blueSMSsender_Config_OK_Button, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 10)
        blueSMSsender_Config_HSizer.Add(self.blueSMSsender_Config_DEL_Button, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 10)
        blueSMSsender_Config_VSizer.Add(blueSMSsender_Config_HSizer, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 0)
        self.blueSMSsender_Config_Panel.SetSizer(blueSMSsender_Config_VSizer)
        blueSMSsender_Config_Sizer.Add(self.blueSMSsender_Config_Panel, 1, wx.EXPAND, 0)
        self.SetSizer(blueSMSsender_Config_Sizer)
        self.Layout()
        self.Centre()
        # end wxGlade
        
    def __do_evt(self):
        self.Bind(wx.EVT_BUTTON, self.AddDevices, id=self.ID_SEARCH)
        self.Bind(wx.EVT_BUTTON, self.OnOk, id=wx.ID_OK)
        if PLATFORM.startswith('win'):
            self.Bind(wx.EVT_CHECKLISTBOX, self.OnCheckListBoxCom, self.blueSMSsender_Config_CListBox)
            self.Bind(wx.EVT_BUTTON, self.OnDeleteCom, id=wx.ID_DELETE)
        else:
            self.Bind(wx.EVT_CHECKLISTBOX, self.OnCheckListBox, self.blueSMSsender_Config_CListBox)
            self.Bind(wx.EVT_BUTTON, self.OnDelete, id=wx.ID_DELETE)
        self.Bind(EVT_UPDATE_LISTCTRL, self.OnBTListDevFound)
        self.Bind(EVT_UPDATE_LISTCTRLCOM, self.OnComListDevFound)
        self.Bind(EVT_UPDATE_TITLE, self.OnUpdateTitle)
        
    def OnUpdateTitle(self,event):
        self.SetTitle(event.value)
        
    def OnComListDevFound(self,event):
        self.InsCListCtrlCom(event.data)
        self.anim.AniStop()
        self.blueSMSsender_Config_Search_Button.Enable(True)

    def OnBTListDevFound(self,event):
        self.InsCListCtrl(event.data)
        self.anim.AniStop()
        self.blueSMSsender_Config_Search_Button.Enable(True)
    
    def InsCListCtrlCom(self,tlist):
        cnt = 0
        for row in tlist:
            self.blueSMSsender_Config_CListBox.Append('Port: %s' % row[2])
            if row[0] == 0:
                self.blueSMSsender_Config_CListBox.Check(cnt,False)
            else:
                self.blueSMSsender_Config_CListBox.Check(cnt,True)
            cnt = cnt + 1
        
    def InsCListCtrl(self,tlist):
        cnt = 0
        for row in tlist:
            self.blueSMSsender_Config_CListBox.Append("%s (%s - Channel:%d)" % (row[1],row[2],row[3]))
            if row[0] == 0:
                self.blueSMSsender_Config_CListBox.Check(cnt,False)
            else:
                self.blueSMSsender_Config_CListBox.Check(cnt,True)
            cnt = cnt + 1
        
    def AddDevices(self,event):
        self.blueSMSsender_Config_Search_Button.Enable(False)
        self.blueSMSsender_Config_CListBox.Clear()
        self.anim = blueSMSsender_OnSearch(self,-1,"")
        self.anim.AniPlay()
        ct = SearchThreads(self)
        ct.Start()

    def OnOk(self,event):
        try:
            flag = False
            for row in range(0,self.blueSMSsender_Config_CListBox.GetCount()):
                if self.blueSMSsender_Config_CListBox.IsChecked(row):
                    flag = True
            if flag:
                self.Destroy()
            else:
                raise NoDeviceChecked
        except NoDeviceChecked:
            errore=_('Error: select a device')
            dlg = wx.MessageDialog(self,errore,_('Error'),wx.OK | wx.ICON_ERROR)
            dlg.ShowModal()
        
    def OnDelete(self,event):
        db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
        db.del_bluetooth()
        db.exit()
        self.blueSMSsender_Config_CListBox.Clear()
        
    def OnDeleteCom(self,event):
        db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
        db.del_com()
        db.exit()
        self.blueSMSsender_Config_CListBox.Clear()
        
    def OnCheckListBoxCom(self,event):
        db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
        index = event.GetSelection()
        for idx in range(0,self.blueSMSsender_Config_CListBox.GetCount()):
            if idx != index: self.blueSMSsender_Config_CListBox.Check(idx,False) 
            status = self.blueSMSsender_Config_CListBox.IsChecked(idx)
            name = self.blueSMSsender_Config_CListBox.GetString(idx).split('Port:')[1].strip()
            if status:
                db.upd_com(name,1)
            else:
                db.upd_com(name,0)
        db.exit()
        
    def OnCheckListBox(self,event):
        db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
        index = event.GetSelection()
        for idx in range(0,self.blueSMSsender_Config_CListBox.GetCount()):
            if idx != index: self.blueSMSsender_Config_CListBox.Check(idx,False) 
            status = self.blueSMSsender_Config_CListBox.IsChecked(idx)
            address = self.blueSMSsender_Config_CListBox.GetString(idx).split('(')[1].split('-')[0].strip()
            if status:
                db.upd_bluetooth(address,1)
            else:
                db.upd_bluetooth(address,0)
        db.exit()

# end of class blueSMSsender_Config

class blueSMSsender_OnSearch(wx.Frame):
    def __init__(self, parent, *args, **kwds):
        kwds["style"] = wx.SIMPLE_BORDER|wx.FRAME_FLOAT_ON_PARENT
        # begin wxGlade: blueSMSsender_OnSearch.__init__
        wx.Frame.__init__(self, parent, size=(34, 34), *args, **kwds)
        self.blueSMSsender_OnSearch_Panel = wx.Panel(self, -1)
        if PLATFORM.startswith('win'):
            ani = animate.Animation('./data/animupdate.gif')
        else:
            ani = animate.Animation('./data/bluetooth.gif')
        self.blueSMSsender_OnSearch_AnimatedCtrl = animate.AnimationCtrl(self,-1,ani)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: blueSMSsender_OnSearch.__set_properties
        self.SetTitle(_("Search Bluetooth Device"))
        _icon = wx.EmptyIcon()
        if PLATFORM.startswith('win'):
            _icon.CopyFromBitmap(wx.Bitmap("./data/update.ico", wx.BITMAP_TYPE_ANY))
        else:
            _icon.CopyFromBitmap(wx.Bitmap("./data/bluetooth.ico", wx.BITMAP_TYPE_ANY))
        self.blueSMSsender_OnSearch_AnimatedCtrl.SetSize(self.blueSMSsender_OnSearch_AnimatedCtrl.GetBestSize())
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: blueSMSsender_OnSearch.__do_layout
        blueSMSsender_OnSearch_Sizer = wx.BoxSizer(wx.VERTICAL)
        blueSMSsender_OnSearch_Sizer.Add(self.blueSMSsender_OnSearch_AnimatedCtrl, 0, wx.ALL|wx.ALIGN_CENTER, 0)
        blueSMSsender_OnSearch_Sizer.Add(self.blueSMSsender_OnSearch_Panel, 1, wx.EXPAND, 0)
        self.SetSizer(blueSMSsender_OnSearch_Sizer)
        #blueSMSsender_OnSearch_Sizer.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade
        self.blueSMSsender_OnSearch_Panel.SetBackgroundColour(wx.Color(255,255,255))
        self.blueSMSsender_OnSearch_AnimatedCtrl.SetBackgroundColour(self.blueSMSsender_OnSearch_Panel.GetBackgroundColour())
        
    def AniPlay(self):
        self.Show(1)
        self.blueSMSsender_OnSearch_AnimatedCtrl.Play()
        
    def AniStop(self):
        self.blueSMSsender_OnSearch_AnimatedCtrl.Stop()
        self.Show(0)

# end of class blueSMSsender_OnSearch
