#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import wx
import sys
from wx.lib.mixins.listctrl import ListCtrlAutoWidthMixin
from wx.lib.mixins.listctrl import TextEditMixin
from wx.lib.mixins.listctrl import CheckListCtrlMixin
import blueSMSsender_SQLliteDB
import blueSMSsender_New_Message

class blueSMSsender_Message_ListControl(wx.ListCtrl,ListCtrlAutoWidthMixin,TextEditMixin,CheckListCtrlMixin):
    def __init__(self, parent, blueSMSsender_Message, id):
        wx.ListCtrl.__init__(self, parent, id, style=wx.LC_REPORT|wx.LC_HRULES|wx.LC_VRULES)
        self.pframe = blueSMSsender_Message
        ListCtrlAutoWidthMixin.__init__(self)
        TextEditMixin.__init__(self)
        CheckListCtrlMixin.__init__(self)
        
    def OnCheckItem(self, index, flag):
        data = self.GetItem(index).GetText()
        if flag:
            self.pframe.rowflagged.append(data)
        else:
            self.pframe.rowflagged.remove(data)

class blueSMSsender_Message(wx.Frame):
    def __init__(self, parent, *args, **kwds):
        # begin wxGlade: blueSMSsender_Message.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, parent, size=(700,500), *args, **kwds)
        self.pframe = parent
        self.blueSMSsender_Message_Panel = wx.Panel(self, -1)
        self.rowflagged = []
        self.ID_LIST = wx.NewId()
        self.blueSMSsender_Message_ListControl = blueSMSsender_Message_ListControl(self.blueSMSsender_Message_Panel, self, self.ID_LIST)
        
        # Menu Bar
        self.blueSMSsender_Message_MenuBar = wx.MenuBar()
        wxglade_tmp_menu = wx.Menu()
        new = wx.MenuItem(wxglade_tmp_menu, wx.ID_NEW, _("New"), _("Save new message"), wx.ITEM_NORMAL)
        new.SetBitmap(wx.Bitmap("./data/New.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(new)
        canc = wx.MenuItem(wxglade_tmp_menu, wx.ID_RESET, _("Delete messages"), _("Delete all the messages saved"), wx.ITEM_NORMAL)
        canc.SetBitmap(wx.Bitmap("./data/Delete.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(canc)
        wxglade_tmp_menu.AppendSeparator()
        wxglade_tmp_menu.Append(wx.ID_EXIT, _("Exit"), _("Return to main view"), wx.ITEM_NORMAL)
        self.blueSMSsender_Message_MenuBar.Append(wxglade_tmp_menu, _("File"))
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(wx.ID_ABOUT, _("About"), _("Show about dialog"), wx.ITEM_NORMAL)
        self.blueSMSsender_Message_MenuBar.Append(wxglade_tmp_menu, "?")
        self.SetMenuBar(self.blueSMSsender_Message_MenuBar)
        # Menu Bar end
        
        # Tool Bar
        self.blueSMSsender_Message_ToolBar = wx.ToolBar(self, -1)
        self.SetToolBar(self.blueSMSsender_Message_ToolBar)
        self.blueSMSsender_Message_ToolBar.AddLabelTool(wx.ID_NEW, _("New"), wx.Bitmap("./data/New.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _("New message"), _("Store a new message"))
        self.blueSMSsender_Message_ToolBar.AddLabelTool(wx.ID_CANCEL, _("Delete selected"), wx.Bitmap("./data/msg_delete.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _("Delete selected"), _("Delete only the selected messages"))
        self.blueSMSsender_Message_ToolBar.AddSeparator()
        self.blueSMSsender_Message_ToolBar.AddLabelTool(wx.ID_RESET, _("Delete messages"), wx.Bitmap("./data/Delete.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _("Delete messages"), _("Delete all the stored messages"))
        self.blueSMSsender_Message_ToolBar.AddLabelTool(wx.ID_EXIT, _("Exit"), wx.Bitmap("./data/Previous.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _("Exit"), _("Return to main view"))
        # Tool Bar end
        self.blueSMSsender_Message_StatusBar = self.CreateStatusBar(1, 0)

        self.__set_properties()
        self.__do_layout()
        self.__do_evt()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: blueSMSsender_Message.__set_properties
        self.SetTitle(_("Messages"))
        _icon = wx.EmptyIcon()
        _icon.CopyFromBitmap(wx.Bitmap("./data/message.ico", wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)
        self.blueSMSsender_Message_ListControl.InsertColumn(0, _("Messages"))
        self.blueSMSsender_Message_ListControl.SetColumnWidth(0,wx.LIST_AUTOSIZE_USEHEADER)
        self.blueSMSsender_Message_ToolBar.Realize()
        self.blueSMSsender_Message_StatusBar.SetStatusWidths([-1])
        db = blueSMSsender_SQLliteDB
        self.pb = db.blueSMSsender_Sdb()
        pb_data = self.pb.sel_message()
        for row in pb_data:
            self.blueSMSsender_Message_ListControl.InsertStringItem(sys.maxint,row[0])
        self.blueSMSsender_Message_StatusBar.SetStatusText(_('Stored messages'))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: blueSMSsender_Message.__do_layout
        blueSMSsender_Message_Sizer = wx.BoxSizer(wx.VERTICAL)
        blueSMSsender_Message_LCSizer = wx.BoxSizer(wx.HORIZONTAL)
        blueSMSsender_Message_LCSizer.Add(self.blueSMSsender_Message_ListControl, 1, wx.EXPAND, 0)
        self.blueSMSsender_Message_Panel.SetSizer(blueSMSsender_Message_LCSizer)
        blueSMSsender_Message_Sizer.Add(self.blueSMSsender_Message_Panel, 1, wx.EXPAND, 0)
        self.SetSizer(blueSMSsender_Message_Sizer)
        self.Layout()
        self.Centre()
        # end wxGlade
        
    def __do_evt(self):
        self.Bind(wx.EVT_CLOSE, self.OnExit)
        self.Bind(wx.EVT_MENU, self.OnNew, id=wx.ID_NEW)
        self.Bind(wx.EVT_MENU, self.OnDelete, id=wx.ID_CANCEL)
        self.Bind(wx.EVT_MENU, self.OnReset, id=wx.ID_RESET)
        self.Bind(wx.EVT_MENU, self.OnExit, id=wx.ID_EXIT)
        self.Bind(wx.EVT_LIST_BEGIN_LABEL_EDIT, self.OnEdit, self.blueSMSsender_Message_ListControl, id=self.ID_LIST)
        self.Bind(wx.EVT_LIST_END_LABEL_EDIT, self.OnSaveMod, self.blueSMSsender_Message_ListControl, id=self.ID_LIST)
        
    def OnEdit(self,event):
        self.old_data = event.GetLabel()
        
    def OnSaveMod(self,event):
        if not event.IsEditCancelled():
            mod_data = event.GetLabel()
            self.pb.upd_message(mod_data,self.old_data)
        
    def OnNew(self,event):
        Mask=blueSMSsender_New_Message.blueSMSsender_New_Message(self,-1,_("New message"))
        Mask.Show(1)
        
    def OnInsert(self,msg):
        try:
            self.pb.ins_message(msg)
            self.blueSMSsender_Message_ListControl.InsertStringItem(sys.maxint,msg)
        except self.pb.IntegrityError:
            dlg = wx.MessageDialog(self,_('Message already inserted'),_('Error'),wx.OK | wx.ICON_ERROR)
            dlg.ShowModal()
            
    def OnDelete(self,event):
        if len(self.rowflagged) > 0:
            for row in self.rowflagged:
                self.pb.del_message(row)
                self.rowflagged.remove(row)
                for idx in range(0, self.blueSMSsender_Message_ListControl.GetItemCount()):
                    if self.blueSMSsender_Message_ListControl.GetItem(idx).GetText() == row:
                        self.blueSMSsender_Message_ListControl.DeleteItem(idx)
                        break
            
    def OnReset(self,event):
        self.blueSMSsender_Message_ListControl.DeleteAllItems()
        self.pb.del_message()
        
    def OnExit(self,event):
        if len(self.rowflagged) == 1:
            self.pframe.InsMessage(self.rowflagged[0])
            self.pb.exit()
            self.Destroy()
        elif len(self.rowflagged) == 0:
            self.pb.exit()
            self.Destroy()
        else:
            dlg = wx.MessageDialog(self,_('Only one selected message is allowed'),_('Caution'),wx.OK | wx.ICON_WARNING)
            dlg.ShowModal()

# end of class blueSMSsender_Message
