#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import wx
import blueSMSsender_SQLliteDB
import blueSMSsender_New_PhoneBook
import sys
from wx.lib.mixins.listctrl import ListCtrlAutoWidthMixin
from wx.lib.mixins.listctrl import TextEditMixin
from wx.lib.mixins.listctrl import CheckListCtrlMixin 
import csv
import os

class blueSMSsender_PhoneBook_ListCtrl(wx.ListCtrl,ListCtrlAutoWidthMixin,TextEditMixin,CheckListCtrlMixin):
    def __init__(self,parent,id):
        wx.ListCtrl.__init__(self, parent, id, style=wx.LC_REPORT)
        self.pframe = parent
        ListCtrlAutoWidthMixin.__init__(self)
        TextEditMixin.__init__(self)
        CheckListCtrlMixin.__init__(self)
        
    def OnCheckItem(self, index, flag):
        data = (self.GetItem(index).GetText(),self.GetItem(index,1).GetText())
        if flag:
            self.pframe.rowflagged.append(data)
        else:
            self.pframe.rowflagged.remove(data)
        self.pframe.blueSMSsender_PhoneBook_TextCtrl.SetFocus()

class blueSMSsender_PhoneBook(wx.Frame):
    def __init__(self, parent, *args, **kwds):
        # begin wxGlade: blueSMSsender_PhoneBook.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, parent, size=(700,500),*args, **kwds)
        self.pframe = parent
        self.blueSMSsender_PhoneBook_Panel = wx.Panel(self, -1)
        
        # Menu Bar
        self.blueSMSsender_PhoneBook_MenuBar = wx.MenuBar()
        wxglade_tmp_menu = wx.Menu()
        new = wx.MenuItem(wxglade_tmp_menu, wx.ID_NEW, _("New"), _("New phonebook entry"), wx.ITEM_NORMAL)
        new.SetBitmap(wx.Bitmap("./data/New.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(new)
        wxglade_tmp_menu.AppendSeparator()
        apri = wx.MenuItem(wxglade_tmp_menu, wx.ID_OPEN, _("Open"), _("Open comma separated file contains phonebook entries"), wx.ITEM_NORMAL)
        apri.SetBitmap(wx.Bitmap("./data/open.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(apri)
        save = wx.MenuItem(wxglade_tmp_menu, wx.ID_SAVE, _("Save"), _("Save comma separated file with the current phonebook entries"), wx.ITEM_NORMAL)
        save.SetBitmap(wx.Bitmap("./data/save.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(save)
        wxglade_tmp_menu.AppendSeparator()
        delete = wx.MenuItem(wxglade_tmp_menu, wx.ID_DELETE, _("Erase phonebook"), _("Delete entire phonebook"), wx.ITEM_NORMAL)
        delete.SetBitmap(wx.Bitmap("./data/Delete.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(delete)
        wxglade_tmp_menu.AppendSeparator()
        close = wx.MenuItem(wxglade_tmp_menu, wx.ID_CLOSE, _("Close"), _("Return to main view"), wx.ITEM_NORMAL)
        close.SetBitmap(wx.Bitmap("./data/Previous.ico", wx.BITMAP_TYPE_ANY))
        wxglade_tmp_menu.AppendItem(close)
        self.blueSMSsender_PhoneBook_MenuBar.Append(wxglade_tmp_menu, _("File"))
        self.SetMenuBar(self.blueSMSsender_PhoneBook_MenuBar)
        # Menu Bar end
        self.blueSMSsender_PhoneBook_StatusBar = self.CreateStatusBar(1, 0)
        
        # Tool Bar
        self.blueSMSsender_PhoneBook_ToolBar = wx.ToolBar(self, -1)
        self.SetToolBar(self.blueSMSsender_PhoneBook_ToolBar)
        self.blueSMSsender_PhoneBook_ToolBar.AddLabelTool(wx.ID_NEW, _("New"), wx.Bitmap("./data/New.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL)
        self.blueSMSsender_PhoneBook_ToolBar.AddLabelTool(wx.ID_DELETE, _("Delete phonebook"), wx.Bitmap("./data/Delete.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, "", "")
        self.blueSMSsender_PhoneBook_ToolBar.AddLabelTool(wx.ID_CLOSE, _("Exit"), wx.Bitmap("./data/Previous.ico", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, "", "")
        # Tool Bar end
        self.ID_LIST = wx.NewId()
        self.blueSMSsender_PhoneBook_ListCtrl = blueSMSsender_PhoneBook_ListCtrl(self,self.ID_LIST)
        self.blueSMSsender_PhoneBook_TextCtrl = wx.TextCtrl(self.blueSMSsender_PhoneBook_Panel, -1, "")
        self.ID_SEARCH = wx.NewId()
        self.blueSMSsender_PhoneBook_SearchButton = wx.Button(self.blueSMSsender_PhoneBook_Panel, self.ID_SEARCH, _("Search"))
        self.blueSMSsender_PhoneBook_CancelButton = wx.Button(self.blueSMSsender_PhoneBook_Panel, wx.ID_CANCEL, _("Cancel"))

        self.__set_properties()
        self.__do_layout()
        self.__do_evt()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: blueSMSsender_PhoneBook.__set_properties
        self.SetTitle(_("Phonebook"))
        _icon = wx.EmptyIcon()
        _icon.CopyFromBitmap(wx.Bitmap("./data/PhoneBook.ico", wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)
        self.blueSMSsender_PhoneBook_ListCtrl.InsertColumn(0, _("Name"))
        self.blueSMSsender_PhoneBook_ListCtrl.InsertColumn(1, _("Phone number"))
        self.blueSMSsender_PhoneBook_StatusBar.SetStatusWidths([-1])
        self.blueSMSsender_PhoneBook_ToolBar.Realize()
        # end wxGlade
        # Populate listctrl
        db = blueSMSsender_SQLliteDB
        self.pb = db.blueSMSsender_Sdb()
        pb_data = self.pb.sel_phonebook()
        for row in pb_data:
            index = self.blueSMSsender_PhoneBook_ListCtrl.InsertStringItem(sys.maxint,row[0])
            self.blueSMSsender_PhoneBook_ListCtrl.SetStringItem(index,1,row[1])
        self.blueSMSsender_PhoneBook_StatusBar.SetStatusText(_('Phonebook loaded'))
        # end populate listctrl
        self.wildcard = "CSV Comma delimited (*.csv)|*.csv|"\
                        "All files (*.*)|*.*"
        self.rowflagged = []
        self.SetWidth(None)
    
    def __do_layout(self):
        # begin wxGlade: blueSMSsender_PhoneBook.__do_layout
        blueSMSsender_PhoneBook_Sizer = wx.BoxSizer(wx.HORIZONTAL)
        blueSMSsender_PhoneBook_CtrlSizer = wx.BoxSizer(wx.VERTICAL)
        blueSMSsender_PhoneBook_GridSizer = wx.GridSizer(1, 2, 5, 5)
        blueSMSsender_PhoneBook_Sizer.Add(self.blueSMSsender_PhoneBook_ListCtrl, 1, wx.EXPAND, 0)
        blueSMSsender_PhoneBook_CtrlSizer.Add(self.blueSMSsender_PhoneBook_TextCtrl, 0, wx.ALL|wx.EXPAND, 5)
        blueSMSsender_PhoneBook_GridSizer.Add(self.blueSMSsender_PhoneBook_SearchButton, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5)
        blueSMSsender_PhoneBook_GridSizer.Add(self.blueSMSsender_PhoneBook_CancelButton, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5)
        blueSMSsender_PhoneBook_CtrlSizer.Add(blueSMSsender_PhoneBook_GridSizer, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_LEFT, 0)
        self.blueSMSsender_PhoneBook_Panel.SetSizer(blueSMSsender_PhoneBook_CtrlSizer)
        blueSMSsender_PhoneBook_Sizer.Add(self.blueSMSsender_PhoneBook_Panel, 1, wx.EXPAND, 0)
        self.SetSizer(blueSMSsender_PhoneBook_Sizer)
        #blueSMSsender_PhoneBook_Sizer.FitInside(self)
        self.Layout()
        self.Centre()
        self.blueSMSsender_PhoneBook_TextCtrl.SetFocus()
        # end wxGlade
        
    def __do_evt(self):
        self.Bind(wx.EVT_BUTTON, self.OnNew, id=wx.ID_NEW)
        self.Bind(wx.EVT_MENU, self.OnNew, id=wx.ID_NEW)
        self.Bind(wx.EVT_CLOSE, self.OnExit)
        self.Bind(wx.EVT_BUTTON, self.OnExit, id=wx.ID_CLOSE)
        self.Bind(wx.EVT_MENU, self.OnExit, id=wx.ID_CLOSE)
        self.Bind(wx.EVT_LIST_BEGIN_LABEL_EDIT, self.OnEdit, self.blueSMSsender_PhoneBook_ListCtrl, id=self.ID_LIST)
        self.Bind(wx.EVT_LIST_END_LABEL_EDIT, self.OnSaveMod, self.blueSMSsender_PhoneBook_ListCtrl, id=self.ID_LIST)
        self.Bind(wx.EVT_BUTTON, self.OnDelete, id=wx.ID_CANCEL)
        self.Bind(wx.EVT_BUTTON, self.OnSearch, id=self.ID_SEARCH)
        self.Bind(wx.EVT_BUTTON, self.OnReset, id=wx.ID_DELETE)
        self.Bind(wx.EVT_MENU, self.OnReset, id=wx.ID_DELETE)
        self.Bind(wx.EVT_MENU, self.OnOpen, id=wx.ID_OPEN)
        self.Bind(wx.EVT_MENU, self.OnSave, id=wx.ID_SAVE)
        self.Bind(wx.EVT_MAXIMIZE, self.SetWidth)
        
    def SetWidth(self,event):
        self.blueSMSsender_PhoneBook_ListCtrl.SetColumnWidth(0,wx.LIST_AUTOSIZE)
        self.blueSMSsender_PhoneBook_ListCtrl.SetColumnWidth(0,wx.LIST_AUTOSIZE_USEHEADER)
        
    def OnExit(self,event):
        if len(self.rowflagged) > 0:
            for row in self.rowflagged:
                self.pframe.InsCustList(row)
        self.pb.exit()
        self.Destroy()
        
    def OnEdit(self,event):
        self.old_data = (self.blueSMSsender_PhoneBook_ListCtrl.GetItem(event.m_itemIndex,0).GetText(),self.blueSMSsender_PhoneBook_ListCtrl.GetItem(event.m_itemIndex,1).GetText())
        
    def OnSaveMod(self,event):
        if not event.IsEditCancelled():
            idx = event.GetIndex()
            col = event.GetColumn()
            data = event.GetLabel()
            if col == 0:
                mod_data = (data,self.blueSMSsender_PhoneBook_ListCtrl.GetItem(idx,1).GetText())
            else:
                mod_data = (self.blueSMSsender_PhoneBook_ListCtrl.GetItem(idx,0).GetText(),data)
            try:
                self.pb.upd_phonebook(mod_data[0],mod_data[1],self.old_data[0],self.old_data[1])
            except self.pb.IntegrityError:
                event.Veto()
                dlg = wx.MessageDialog(self,_('Phonebook entry already'),_('Error'),wx.OK | wx.ICON_ERROR)
                dlg.ShowModal()
        
    def OnNew(self,event):
        Mask=blueSMSsender_New_PhoneBook.blueSMSsender_New_PhoneBook(self,-1,_("New phonebook entry"))
        Mask.Show(1)
        
    def OnInsert(self,items):
        try:
            self.pb.ins_phonebook(items[0],items[1])
            index = self.blueSMSsender_PhoneBook_ListCtrl.InsertStringItem(sys.maxint,items[0])
            self.blueSMSsender_PhoneBook_ListCtrl.SetStringItem(index,1,items[1])
        except self.pb.IntegrityError:
            dlg = wx.MessageDialog(self,_('Phonebook entry already'),_('Error'),wx.OK | wx.ICON_ERROR)
            dlg.ShowModal()
    
    def OnOpen(self,event):
        dial=wx.FileDialog(self,_("Open file"),".",wildcard=self.wildcard)
        if dial.ShowModal() == wx.ID_OK:
            csvfile = csv.reader(open(dial.GetPath()),delimiter=';')
            self.blueSMSsender_PhoneBook_ListCtrl.DeleteAllItems()
            self.OnReset(None)
            for tmp in csvfile:
                if len(tmp) == 2:
                    if len(tmp[0]) > 0 or len(tmp[1]): 
                        row = []
                        try:
                            row.append(tmp[0].decode('utf-8').strip())
                            row.append(tmp[1].decode('utf-8').replace(' ',''))
                        except UnicodeDecodeError:
                            row.append(tmp[0])
                            row.append(tmp[1].replace(' ',''))
                        try:
                            self.pb.ins_phonebook(row[0],row[1])
                        except self.pb.IntegrityError:
                            pass
            self.ListRefresh()
                        
    def ListRefresh(self):
        self.blueSMSsender_PhoneBook_ListCtrl.DeleteAllItems()
        pb_data = self.pb.sel_phonebook()
        for row in pb_data:
            index = self.blueSMSsender_PhoneBook_ListCtrl.InsertStringItem(sys.maxint,row[0])
            self.blueSMSsender_PhoneBook_ListCtrl.SetStringItem(index,1,row[1])        
                
    def OnSave(self,event):
        dlg = wx.FileDialog(self, _("Save file"), os.path.expanduser("~"), "*.csv", wildcard=self.wildcard, style=wx.SAVE)
        if dlg.ShowModal() == wx.ID_OK:
            csvfile = csv.writer(open(dlg.GetPath(),'wb'),delimiter=';',lineterminator='\n')
            for row in range(0,self.blueSMSsender_PhoneBook_ListCtrl.GetItemCount()):
                tmp = []
                tmp.append(self.blueSMSsender_PhoneBook_ListCtrl.GetItem(row,0).GetText())
                tmp.append(self.blueSMSsender_PhoneBook_ListCtrl.GetItem(row,1).GetText())
                csvfile.writerow([s.encode("utf-8") for s in tmp])                
    
    def OnDelete(self,event):
        if len(self.rowflagged) > 0:
            for cnt in range(len(self.rowflagged)-1,-1,-1):
                row = self.rowflagged[cnt]
                self.pb.del_phonebook(row[0],row[1])                
                for idx in range(self.blueSMSsender_PhoneBook_ListCtrl.GetItemCount()):
                    if self.blueSMSsender_PhoneBook_ListCtrl.GetItem(idx).GetText() == row[0] and self.blueSMSsender_PhoneBook_ListCtrl.GetItem(idx,1).GetText() == row[1]:
                        self.blueSMSsender_PhoneBook_ListCtrl.DeleteItem(idx)
                        break
                self.rowflagged.pop(cnt)
            
    def OnSearch(self,event):
        txt_search = self.blueSMSsender_PhoneBook_TextCtrl.GetValue()
        if txt_search:
            self.blueSMSsender_PhoneBook_ListCtrl.DeleteAllItems()
            pb_data = self.pb.sel_phonebook(txt_search)
            for row in pb_data:
                index = self.blueSMSsender_PhoneBook_ListCtrl.InsertStringItem(sys.maxint,row[0])
                self.blueSMSsender_PhoneBook_ListCtrl.SetStringItem(index,1,row[1])
        else:
            self.blueSMSsender_PhoneBook_ListCtrl.DeleteAllItems()
            pb_data = self.pb.sel_phonebook()
            for row in pb_data:
                index = self.blueSMSsender_PhoneBook_ListCtrl.InsertStringItem(sys.maxint,row[0])
                self.blueSMSsender_PhoneBook_ListCtrl.SetStringItem(index,1,row[1])
                if (row[0],row[1]) in self.rowflagged:
                    self.blueSMSsender_PhoneBook_ListCtrl.CheckItem(index, True)
    
    def OnReset(self,event):
        if event != None:
            dlg = wx.MessageDialog(self,_("You are about to delete the entire phonebook\nAre you sure you want to continue?"),_("Caution"),wx.YES_NO | wx.NO_DEFAULT | wx.ICON_WARNING)
            if dlg.ShowModal() == wx.ID_YES:
                self.blueSMSsender_PhoneBook_ListCtrl.DeleteAllItems()
                self.pb.del_phonebook()
        else:
            self.blueSMSsender_PhoneBook_ListCtrl.DeleteAllItems()
            self.pb.del_phonebook()

# end of class blueSMSsender_PhoneBook


