#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import sqlite3
import exceptions
import os

class blueSMSsender_Sdb:
    def __init__(self):
        self.IntegrityError = exceptions.Exception
        pathdb=os.path.expanduser("~/.blueSMSsender/")
        if not os.path.isdir(pathdb):
            os.mkdir(pathdb)
        self.db = sqlite3.connect(pathdb+'blueSMSsender.sdb')
        cur =  self.db.cursor()
        cur.execute('CREATE TABLE IF NOT EXISTS phonebook (customer text,number text, PRIMARY KEY(customer,number))')
        cur.execute('CREATE TABLE IF NOT EXISTS message(message text, PRIMARY KEY(message))')
        cur.execute('CREATE TABLE IF NOT EXISTS BTDevices(active int default 0, name text, address text, port integer, PRIMARY KEY(address))')
        cur.execute('CREATE TABLE IF NOT EXISTS COMDevices(active int default 0, port integer, name text)')
            
    def exit(self):
        self.db.close()
    
    def ins_phonebook(self,name,number):
        try:
            cur =  self.db.cursor()
            cur.execute("INSERT INTO phonebook (customer,number) VALUES ('"+name+"','"+number+"')")
            self.db.commit()
        except sqlite3.IntegrityError:
            raise self.IntegrityError
        
    def ins_message(self,msg):
        try:
            cur =  self.db.cursor()
            cur.execute("INSERT INTO message (message) VALUES ('"+msg+"')")
            self.db.commit()
        except sqlite3.IntegrityError:
            raise self.IntegrityError
    
    def ins_com(self,comlist):
        try:
            cur =  self.db.cursor()
            for com in comlist:
                cur.execute("INSERT INTO COMDevices (port,name) VALUES ('"+str(com[0])+"','"+str(com[1])+"')")
            self.db.commit()
        except sqlite3.IntegrityError:
            raise self.IntegrityError
    
    def upd_phonebook(self,name,number,old_name,old_number):
        cur =  self.db.cursor()
        cur.execute("UPDATE phonebook SET customer='"+name+"',number='"+number+"' WHERE customer='"+old_name+"' AND number='"+old_number+"'")
        self.db.commit()
    
    def upd_com(self,name,status):
        cur =  self.db.cursor()
        if status:
            cur.execute("UPDATE COMDevices SET active=1 WHERE name='"+name+"'")
        else:
            cur.execute("UPDATE COMDevices SET active=0 WHERE name='"+name+"'")
        self.db.commit()
    
    def upd_message(self,new_msg,old_msg):
        cur =  self.db.cursor()
        cur.execute("UPDATE message SET message='"+new_msg+"' WHERE message='"+old_msg+"'")
        self.db.commit()
        
    def upd_bluetooth(self,address,status):
        cur =  self.db.cursor()
        if status:
            cur.execute("UPDATE BTDevices SET active=1 WHERE address='"+address+"'")
        else:
            cur.execute("UPDATE BTDevices SET active=0 WHERE address='"+address+"'")
        self.db.commit()     
    
    def ins_bluetooth(self,BTDList):
        try:
            presence = False
            cur =  self.db.cursor()
            address = self.sel_bluetooth()    
            for item in BTDList:
                if len(address) > 0:
                    for adr in address:
                        if item[1] == adr[2]:
                            presence = True
                if presence == False:
                    cur.execute("INSERT INTO BTDevices (name, address, port) VALUES ('"+item[0]+"','"+item[1]+"',"+str(item[2])+")")
                else:
                    cur.execute("UPDATE BTDevices SET name = '"+item[0]+"',port = "+str(item[2])+" WHERE address = '"+item[1]+"'")
                self.db.commit()
        except sqlite3.IntegrityError:
            raise self.IntegrityError
    
    def sel_phonebook(self,name=None,number=None):
        cur =  self.db.cursor()
        if name == None and number == None: 
            cur.execute('SELECT * FROM phonebook order by customer asc')
        elif name != None and number == None:
            cur.execute("SELECT * FROM phonebook WHERE customer LIKE '%"+name+"%' order by customer asc")
        elif name == None and number != None:
            cur.execute("SELECT * FROM phonebook WHERE number LIKE '%"+number+"%' order by customer asc")
        elif name != None and number != None:
            cur.execute("SELECT * FROM phonebook WHERE number LIKE '%"+number+"%' AND customer LIKE '%"+name+"%' order by customer asc")
        tmp_data = []
        for row in cur:
            tmp_data.append(row)
        return tmp_data
    
    def sel_bluetooth(self,active=None,name=None,address=None):
        cur =  self.db.cursor()
        if name == None and address == None and active == None: 
            cur.execute('SELECT * FROM BTDevices order by name asc')
        elif name != None and address == None and active == None:
            cur.execute("SELECT * FROM BTDevices WHERE name LIKE '%"+name+"%' order by customer asc")
        elif name == None and address != None and active == None:
            cur.execute("SELECT * FROM BTDevices WHERE address LIKE '%"+address+"%' order by customer asc")
        elif name == None and address == None and active != None:
            cur.execute("SELECT * FROM BTDevices WHERE active LIKE '%"+str(active)+"%'")
        tmp_data = []
        for row in cur:
            tmp_data.append(row)
        return tmp_data
    
    def sel_com(self,active=None,name=None,port=None):
        cur =  self.db.cursor()
        if name == None and port == None and active == None: 
            cur.execute('SELECT * FROM COMDevices order by name asc')
        elif name != None and port == None and active == None:
            cur.execute("SELECT * FROM COMDevices WHERE name LIKE '%"+name+"%' order by name asc")
        elif name == None and port != None and active == None:
            cur.execute("SELECT * FROM COMDevices WHERE port LIKE '%"+port+"%' order by name asc")
        elif name == None and port == None and active != None:
            cur.execute("SELECT * FROM COMDevices WHERE active LIKE '%"+str(active)+"%'")
        tmp_data = []
        for row in cur:
            tmp_data.append(row)
        return tmp_data
    
    def sel_message(self,msg=None):
        cur =  self.db.cursor()
        if msg == None: 
            cur.execute('SELECT * FROM message order by message asc') 
        else:
            cur.execute("SELECT * FROM message WHERE message LIKE '%"+msg+"%' order by customer asc")
        tmp_data = []
        for row in cur:
            tmp_data.append(row)
        return tmp_data
    
    def check_phonebook(self,name=None,number=None):
        cur =  self.db.cursor()
        if name == None and number == None: 
            cur.execute('SELECT count(*) FROM phonebook order by customer asc')
        elif name != None and number == None:
            cur.execute("SELECT count(*) FROM phonebook WHERE customer LIKE '%"+name+"%'")
        elif name == None and number != None:
            cur.execute("SELECT count(*) FROM phonebook WHERE number LIKE '%"+number+"%'")
        elif name != None and number != None:
            cur.execute("SELECT count(*) FROM phonebook WHERE number LIKE '%"+number+"%' AND customer LIKE '%"+name+"%'")
        for row in cur:
            flag = row[0]
        if flag == 0:
            return False
        else:
            return True
    
    def del_phonebook(self,name=None,number=None):
        cur = self.db.cursor()
        if name == None and number == None:
            cur.execute("DELETE FROM phonebook")
        else:
            cur.execute("DELETE FROM phonebook WHERE customer = '"+name+"' and number = '"+number+"'")
        self.db.commit()
    
    def del_bluetooth(self):
        cur = self.db.cursor()
        cur.execute("DELETE FROM BTDevices")
        self.db.commit()
    
    def del_com(self):
        cur = self.db.cursor()
        cur.execute("DELETE FROM COMDevices")
        self.db.commit()    
        
    def del_message(self,msg=None):
        cur = self.db.cursor()
        if msg == None:
            cur.execute("DELETE FROM message")
        else:
            cur.execute("DELETE FROM message WHERE message = '"+msg+"'")
        self.db.commit()
