#-------------------------------------------------------------------------------
# Copyright (c) 2009 Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com>.
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Contributors:
#     Giuseppe Buzzanca (PiDy) <giuseppebuzzanca@gmail.com> - initial API and implementation
#-------------------------------------------------------------------------------

import serial
import blueSMSsender_exceptions
import blueSMSsender_SQLliteDB

class blueSMSsender_Serial():
    
    def __init__(self,port=None):
        if port == None:
            available = []
            for i in range(256):
                try:
                    s = serial.Serial(i)
                    s.write('AT+GMM\r')
                    reply = ''
                    if s.read() != '':
                        while not (reply.endswith(('OK\r\n','ERROR\r\n','> '))):
                            reply += s.read()
                        name=reply[8:reply.find('OK')-4]
                        available.append( (i, s.portstr+' ('+name+')'))
                    s.close()   #explicit close 'cause of delayed GC in java
                except serial.SerialException:
                    pass
            db = blueSMSsender_SQLliteDB.blueSMSsender_Sdb()
            db.del_com()
            db.ins_com(available)
            db.exit()
        else:
            try:
                self.__connect = True
                self.__connection = serial.Serial(port)
                self.__sendATCommand('ATE0')
                self.__sendATCommand('ATZ')
                self.__sendATCommand('AT+CMGF=1')
                characterSets = self.__getSupportedCharacterSets()
                if '"8859-1"' in characterSets:
                    self.__setCharacterSet('"8859-1"')
                    self.fEncode="8859-1"
            except:
                self.__connect = False
                self.__raiseOnNoneSocket('BluetoothConnection: connection error')
    
    def Send(self, number, message):
        if self.__connect == True:
            if self.fEncode == '"8859-1"': message = message.encode('iso-8859-1')
            self.__sendATCommand('AT+CMGS="' + number + '"\r')
            self.__sendATCommand(message + chr(26), False)
        else:
            self.__raiseOnNoneSocket('BluetoothConnection: not connected')
    
    def __parseCommaseperatedList(self, list):
        start = list.find('(') + 1
        end = list.rfind(')')
        return list[start:end].split(',')
    
    def __setCharacterSet(self, characterSet):
        self.__sendATCommand('AT+CSCS=' + characterSet)
    
    def __sendATCommand(self, atCommand, lineBreak = True):
        command = atCommand
        if lineBreak:
            command += '\r'
        self.__connection.write(command) 
        reply = ''
        while not (reply.endswith(('OK\r\n','ERROR\r\n','> '))):
            reply += self.__connection.read()
            if reply.find('+CMS ERROR') != -1: break
        if reply.endswith(('OK\r\n','> ')):
            end = reply.rfind('\r\nOK\r\n')
            return reply[2:end]
        else:
            self.__raiseOnNoneSocket('AT Command not supported by phone: '+atCommand[:-1])
        
    def Close(self):
        if self.__connect == True:
            self.__connection.close()
            self.__connect = False
        else:
            self.__raiseOnNoneSocket('BluetoothConnection: not connected')
            
    def __getSupportedCharacterSets(self):
        response = self.__sendATCommand('AT+CSCS=?')
        return self.__parseCommaseperatedList(response)
    
    def __raiseOnNoneSocket(self, message):
        raise blueSMSsender_exceptions.SerialConnectionError, message
